<template>
  <div class="controls">
    <el-tooltip content="播放/暂停" placement="top" :open-delay="500">
      <el-button class="control-btn" circle @click="$emit('toggle-play')">
        <i :class="isPlaying ? 'el-icon-video-pause' : 'el-icon-video-play'"></i>
      </el-button>
    </el-tooltip>

    <el-tooltip content="设备信息" placement="top" :open-delay="500">
      <el-button class="control-btn" circle @click="$emit('show-device-info')">
        <i class="el-icon-info"></i><el-icon><VideoCamera /></el-icon>
      </el-button>
    </el-tooltip>

    <el-tooltip content="云台操作" placement="top" :open-delay="500">
      <el-button class="control-btn" circle @click="$emit('toggle-ptz')">
        <i class="el-icon-help"></i>
      </el-button>
    </el-tooltip>

    <el-tooltip content="旋转画面" placement="top" :open-delay="500">
      <el-button class="control-btn" circle @click="$emit('rotate-video')">
        <i class="el-icon-refresh"></i>
      </el-button>
    </el-tooltip>

    <el-tooltip content="截图" placement="top" :open-delay="500">
      <el-button class="control-btn" circle @click="$emit('take-snapshot')">
        <i class="el-icon-camera"></i>
      </el-button>
    </el-tooltip>

    <el-tooltip :content="isRecording ? '结束录制' : '开始录制'" placement="top" :open-delay="500">
      <el-button 
        class="control-btn" 
        circle 
        @click="$emit('toggle-recording')"
        :type="isRecording ? 'primary' : ''"
      >
        <i class="el-icon-video-camera"></i>
      </el-button>
    </el-tooltip>

    <el-tooltip :content="isTalking ? '结束喊话' : '喊话'" placement="top" :open-delay="500">
      <el-button 
        class="control-btn" 
        circle 
        @click="$emit('toggle-talk')" 
        :type="isTalking ? 'primary' : ''"
      >
        <i class="el-icon-microphone"></i>
      </el-button>
    </el-tooltip>

    <el-tooltip content="全屏" placement="top" :open-delay="500">
      <el-button class="control-btn" circle @click="$emit('fullscreen')">
        <i class="el-icon-full-screen"></i>
      </el-button>
    </el-tooltip>
  </div>
</template>

<script>
export default {
  name: 'VideoControls',
  
  props: {
    isPlaying: {
      type: Boolean,
      default: false
    },
    isRecording: {
      type: Boolean,
      default: false
    },
    isTalking: {
      type: Boolean,
      default: false
    }
  },

  emits: [
    'toggle-play',
    'show-device-info',
    'toggle-ptz',
    'rotate-video',
    'take-snapshot',
    'toggle-recording',
    'toggle-talk',
    'fullscreen'
  ]
}
</script>

<style scoped>
.controls {
  padding: 12px 20px;
  display: flex;
  gap: 12px;
  justify-content: flex-end;
  width: 100%;
  z-index: 1000;
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  transition: opacity 0.3s ease;
  /* opacity: 0; */
}

.control-btn {
  padding: 8px !important;
  border: none !important;
  background-color: rgba(255, 255, 255, 0) !important;
  margin: 0 4px !important;
  transition: all 0.2s cubic-bezier(0.4, 0, 0.2, 1);
  border-radius: 50% !important;
  width: 40px !important;
  height: 40px !important;
  display: flex !important;
  align-items: center !important;
  justify-content: center !important;
  backdrop-filter: blur(4px);
  -webkit-backdrop-filter: blur(4px);
}

.control-btn:hover {
  background-color: rgba(255, 255, 255, 0.25) !important;
  transform: translateY(-2px) scale(1.05);
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.4);
}

.control-btn:active {
  background-color: rgba(255, 255, 255, 0.3) !important;
  transform: translateY(0) scale(0.98);
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.3);
}

.control-btn i {
  color: #fff;
  font-size: 18px;
  text-shadow: 0 1px 3px rgba(0, 0, 0, 0.3);
  transition: all 0.2s ease;
}

.control-btn:hover i {
  transform: scale(1.1);
}

.controls::before {
  content: '';
  position: absolute;
  bottom: 0;
  left: 0;
  right: 0;
  height: 120px;
  pointer-events: none;
  z-index: -1;
}

:fullscreen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

:-webkit-full-screen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

:-moz-full-screen .controls {
  bottom: 0;
  padding-bottom: 30px;
}

/* 喊话按钮激活状态 */
.control-btn.el-button--primary {
  background-color: #409eff !important;
}

.control-btn.el-button--primary i {
  color: #fff;
}
</style>